@@ -12,27 +12,10 @@ our $alien_key = 'XXXALIENXXX';
     $Wx::dlls = XXXDLLSXXX;
 }
 
-$VERSION = '0.98_01'; # bootstrap will catch wrong versions
+$VERSION = '0.9701_01'; # bootstrap will catch wrong versions
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
-
-#
-# Set Front Process on Mac
-#
-# Mac will be set to front process unless we are in test harness or
-# and enivronment var is set
-# e.g. In a syntax checking editor, set environment variable
-# WXPERL_OPTIONS to include the string NO_MAC_SETFRONTPROCESS
-
-sub MacSetFrontProcess {
-    return if(  ( !defined( &Wx::_MacSetFrontProcess ) )
-              #||( exists($ENV{HARNESS_ACTIVE}) && $ENV{HARNESS_ACTIVE} )
-              ||( exists($ENV{WXPERL_OPTIONS}) && $ENV{WXPERL_OPTIONS} =~ /NO_MAC_SETFRONTPROCESS/)
-              );
-    Wx::_MacSetFrontProcess();
-}
-
 #
 # XSLoader/DynaLoader wrapper
 #
@@ -86,14 +69,14 @@ sub _init_binary_loader {
 }
 
 sub _start {
+
     &_init_binary_loader;
     $wx_path = $wx_binary_loader->set_binary_path;
     wx_boot( 'Wx', $XS_VERSION ) if!$wx_binary_loader->boot_overload;
     _boot_Constant( 'Wx', $XS_VERSION );
     _boot_GDI( 'Wx', $XS_VERSION );
 
-    Load( 1 );
-    Wx::MacSetFrontProcess();
+    Load();
 }
 
 # legacy load functions
